@@ -1,4 +1,5 @@
 from __future__ import print_function, with_statement
+
 import sys
 from os import path, makedirs
 
@@ -32,7 +33,7 @@ def open_file(file_path, mode, action):
 
 def print_error(error_text):
     """Prints red text."""
-    print("\033[91mERROR: {}\033[0m".format(error_text))
+    print("\033[91mUSAGE ERROR: {}\033[0m".format(error_text))
 
 
 def print_bold(bold_text):
@@ -41,3 +42,23 @@ def print_bold(bold_text):
 
 def is_interactive():
     return sys.stdin.isatty()
+
+
+def print_no_existing_profile_message():
+    print_error(u"No existing profile.")
+    print_set_profile_help()
+
+
+def print_set_profile_help():
+    print(u"")
+    print(u"To add a profile, use: ")
+    print_bold(u"\tcode42 profile set --profile <profile-name> -s <authority-URL> -u <username>")
+    print(u"")
+
+
+def get_url_parts(url_str):
+    parts = url_str.split(u":")
+    port = None
+    if len(parts) > 1 and parts[1] != u"":
+        port = int(parts[1])
+    return parts[0], port
